summaryrefslogtreecommitdiffstats
path: root/src/video_core/shader/shader_ir.h
diff options
context:
space:
mode:
authorLioncash <mathew1800@gmail.com>2019-07-16 16:31:17 +0200
committerLioncash <mathew1800@gmail.com>2019-07-17 01:47:43 +0200
commit60926ac16b1c987f50b965292baa47023f46eb60 (patch)
tree6d889159497ec2282dbf20c82711692c3433d535 /src/video_core/shader/shader_ir.h
parentshader_ir: Remove unused includes (diff)
downloadyuzu-60926ac16b1c987f50b965292baa47023f46eb60.tar
yuzu-60926ac16b1c987f50b965292baa47023f46eb60.tar.gz
yuzu-60926ac16b1c987f50b965292baa47023f46eb60.tar.bz2
yuzu-60926ac16b1c987f50b965292baa47023f46eb60.tar.lz
yuzu-60926ac16b1c987f50b965292baa47023f46eb60.tar.xz
yuzu-60926ac16b1c987f50b965292baa47023f46eb60.tar.zst
yuzu-60926ac16b1c987f50b965292baa47023f46eb60.zip
Diffstat (limited to 'src/video_core/shader/shader_ir.h')
-rw-r--r--src/video_core/shader/shader_ir.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/video_core/shader/shader_ir.h b/src/video_core/shader/shader_ir.h
index 5664b2939..59a083d90 100644
--- a/src/video_core/shader/shader_ir.h
+++ b/src/video_core/shader/shader_ir.h
@@ -207,8 +207,8 @@ private:
Node GetInternalFlag(InternalFlag flag, bool negated = false);
/// Generates a node representing a local memory address
Node GetLocalMemory(Node address);
- /// Generates a temporal, internally it uses a post-RZ register
- Node GetTemporal(u32 id);
+ /// Generates a temporary, internally it uses a post-RZ register
+ Node GetTemporary(u32 id);
/// Sets a register. src value must be a number-evaluated node.
void SetRegister(NodeBlock& bb, Tegra::Shader::Register dest, Node src);
@@ -218,8 +218,8 @@ private:
void SetInternalFlag(NodeBlock& bb, InternalFlag flag, Node value);
/// Sets a local memory address. address and value must be a number-evaluated node
void SetLocalMemory(NodeBlock& bb, Node address, Node value);
- /// Sets a temporal. Internally it uses a post-RZ register
- void SetTemporal(NodeBlock& bb, u32 id, Node value);
+ /// Sets a temporary. Internally it uses a post-RZ register
+ void SetTemporary(NodeBlock& bb, u32 id, Node value);
/// Sets internal flags from a float
void SetInternalFlagsFromFloat(NodeBlock& bb, Node value, bool sets_cc = true);